package com.rjconsultores.ventaboletos.service;

import com.rjconsultores.ventaboletos.entidad.VigenciaTarifa;
import com.rjconsultores.ventaboletos.exception.BusinessException;


public interface TarifaOficialService {

	/**
	 * Gera as tarifas de acordo o clculo do coeficiente tarifrio.<br/>
	 * 
	 * Frmula: (KM * Coeficiente Tarifrio)
	 * 
	 * Se o parametro ruta no for informado, ser gerado tarifas para todas as
	 * rutas. <br/>
	 * 
	 * Obs.: Essa opero apenas gera tarifas que ainda no esto geradas<br/>
	 * 
	 * @param rutaId
	 * @param orgaoConcedenteId TODO
	 * @return A quantidade de registros afetadas
	 */
	public Integer gerarTarifaPorCoeficiente(Integer rutaId, Integer orgaoConcedenteId);

	/**
	 * Atualiza as tarifas de acordo o clculo do coeficiente tarifrio.<br/>
	 * 
	 * Frmula: (KM * Coeficiente Tarifrio)
	 * 
	 * Se o parametro ruta no for informado, ser atualizado as tarifas para
	 * todas as rutas.<br/>
	 * 
	 * @param rutaId
	 * @param orgaoConcedenteId TODO
	 * @return TODO
	 */
	public Integer atualizarTarifaPorCoeficiente(Integer rutaId, Integer orgaoConcedenteId);
	
	/**
	 * Gera as novas tarifas e atualiza as j existentes
	 * 
	 * Utiliza os mtodos {@link #gerarTarifaPorCoeficiente(Integer, Integer)} e {@link #atualizarTarifaPorCoeficiente(Integer, Integer)}
	 * 
	 * @param rudaId
	 * @param orgaoConcedenteId 
	 * @return - Retorna o total de registros inseridos + atualizados
	 */
	public Integer gerarAtualizarTarifaPorCoeficiente(Integer rudaId, Integer orgaoConcedenteId) throws BusinessException ;
	
	/**
	 * Copia a tarifa oficial para a tabela de tarifa de acordo com a vigencia especificada
	 * @param vigenciaTarifa
	 */
	public void copiarParaTarifa(VigenciaTarifa vigenciaTarifa);
	
	/**
	 * Atualiza a taxa de embarque da entidade TarifaOficial.<br/>
	 * 
	 * Para o clculo,  usado a seguinte lgica:<br/>
	 * 		- Atualiza de acordo a tabela TAXA_EMBARQUE_PARADA por kilometragem<br/> 
	 * 		- Atualiza de acordo a tabela TAXA_EMBARQUE por kilometragem<br/>
	 * 		- Atualiza de acordo a tabela TAXA_EMBARQUE_PARADA por valor fixo<br/>
	 * 
	 * A sequencia acima indica a ordem de atualizao da taxa de embarque.<br/>
	 * 
	 * A taxa de embarque mais restritiva fica por ltimo (TAXA_EMBARQUE_PARADA por valor fixo)
	 * 
	 * @param rutaId - Se informado, ser atualizado apenas a taxa de embarque da ruta informada
	 * @param orgaoConcedenteId TODO
	 */
	public void atualizarTaxaEmbarque(Integer rutaId, Integer orgaoConcedenteId);
	
	
	/**
	 * Atualiza o seguro de acordo a kilometragem do trecho
	 * 
	 * @param rutaId - Se informado, ser filtrado pela ruta
	 * @param orgaoId -Campo obrigatrio
	 */
	public void atualizarSeguroPorKm(Integer rutaId,Integer orgaoId) throws BusinessException;
	
	/**
	 * Atualiza o seguro de acordo o valor da tarifa
	 * 
	 * @param rutaId - Se informado, ser filtrado pela ruta
	 * @param orgaoId -Campo obrigatrio
	 * 
	 */
	public void atualizarSeguroPorTarifa(Integer rutaId, Integer orgaoId) throws BusinessException;
	
	
	/**
	 * Executa tanto o {@link #atualizarSeguroPorKm(Integer, Integer)} quanto {@link #atualizarSeguroPorTarifa(Integer, Integer)}
	 * 
	 * @param rutaId
	 * @param orgaoId
	 * @throws BusinessException
	 */
	public void atualizarSeguro(Integer rutaId, Integer orgaoId) throws BusinessException;
	
	

}
